# Test Native Convert

[Gimpformats Index](../README.md#gimpformats-index) / [Test Informal](./index.md#test-informal) / Test Native Convert

> Auto-generated documentation for [test_informal.test_native_convert](../../../test_informal/test_native_convert.py) module.
- [Test Native Convert](#test-native-convert)
